@@ -49,7 +49,7 @@ EV - perl interface to libev, a high performance full-featured event loop
    };
    
    # MAINLOOP
-   EV::run;                # loop until EV::unloop is called or all watchers stop
+   EV::run;                # loop until EV::break is called or all watchers stop
    EV::run EV::RUN_ONCE;   # block until at least one event could be handled
    EV::run EV::RUN_NOWAIT; # try to handle same events, but do not block
 
@@ -121,7 +121,7 @@ package EV;
 use common::sense;
 
 BEGIN {
-   our $VERSION = '4.16';
+   our $VERSION = '4.20';
    use XSLoader;
    local $^W = 0; # avoid spurious warning
    XSLoader::load "EV", $VERSION;
@@ -298,7 +298,7 @@ or EV::BACKEND_EPOLL).
 =item $active = $loop->run ([$flags])
 
 Begin checking for events and calling callbacks. It returns when a
-callback calls EV::unloop or the flasg are nonzero (in which case the
+callback calls EV::break or the flasg are nonzero (in which case the
 return value is true) or when there are no active watchers which reference
 the loop (keepalive is true), in which case the return value will be
 false. The returnv alue can generally be interpreted as "if true, there is
